@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -176,9 +176,15 @@ register_mechanism (MsdDatetimeMechanism *mechanism)
 {
         GError *error = NULL;
 
-        mechanism->priv->auth = polkit_authority_get ();
+        mechanism->priv->auth = polkit_authority_get_sync (NULL, &error);
+        if (mechanism->priv->auth == NULL) {
+                if (error != NULL) {
+                        g_critical ("error getting system bus: %s", error->message);
+                        g_error_free (error);
+                }
+                goto error;
+        }
 
-        error = NULL;
         mechanism->priv->system_bus_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
         if (mechanism->priv->system_bus_connection == NULL) {
                 if (error != NULL) {
