@@ -499,11 +499,17 @@ do_media_action (MsdMediaKeysManager *manager)
 }
 
 static void
-do_exit_action (MsdMediaKeysManager *manager)
+do_shutdown_action (MsdMediaKeysManager *manager)
 {
         execute (manager, "mate-session-save --shutdown-dialog", FALSE, FALSE);
 }
 
+static void
+do_logout_action (MsdMediaKeysManager *manager)
+{
+        execute (manager, "mate-session-save --logout-dialog", FALSE, FALSE);
+}
+
 static void
 do_eject_action_cb (GDrive              *drive,
                     GAsyncResult        *res,
@@ -923,8 +929,11 @@ do_action (MsdMediaKeysManager *manager,
 #endif
                 break;
         case POWER_KEY:
-                do_exit_action (manager);
+                do_shutdown_action (manager);
                 break;
+	case LOGOUT_KEY:
+		do_logout_action (manager);
+		break;
         case EJECT_KEY:
                 do_eject_action (manager);
                 break;
