@@ -42,7 +42,7 @@
 
 #define MSD_XRDB_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MSD_TYPE_XRDB_MANAGER, MsdXrdbManagerPrivate))
 
-#define SYSTEM_AD_DIR    DATADIR "/xrdb"
+#define SYSTEM_AD_DIR    SYSCONFDIR "/xrdb"
 #define GENERAL_AD       SYSTEM_AD_DIR "/General.ad"
 #define USER_AD_DIR      ".config/mate/xrdb"
 #define USER_X_RESOURCES ".Xresources"
